from django.contrib.auth.models import User
from django.http import HttpResponse
from django.test import TestCase
from django.test.client import RequestFactory

from organizations.models import Organization, OrganizationUser
from organizations.tests.utils import request_factory_login
from organizations.mixins import (OrganizationMixin, OrganizationUserMixin,
        MembershipRequiredMixin, AdminRequiredMixin, OwnerRequiredMixin)


class ViewStub(object):
    def __init__(self, **kwargs):
        self.kwargs = kwargs

    def dispatch(self, request, *args, **kwargs):
        return HttpResponse("Success")


class OrgView(OrganizationMixin, ViewStub):
    """A testing view class"""
    pass


class UserView(OrganizationUserMixin, ViewStub):
    """A testing view class"""
    pass


class ObjectMixinTests(TestCase):

    fixtures = ['users.json', 'orgs.json']

    def setUp(self):
        self.foo = Organization.objects.get(name='Foo Fighters')
        self.dave = OrganizationUser.objects.get(user__username='dave',
                organization=self.foo)

    def test_get_org_object(self):
        view = OrgView(organization_pk=self.foo.pk)
        self.assertEqual(view.get_object(), self.foo)

    def test_get_user_object(self):
        view = UserView(organization_pk=self.foo.pk, user_pk=self.dave.pk)
        self.assertEqual(view.get_object(), self.dave)
        self.assertEqual(view.get_organization(), self.foo)

    def test_get_model(self):
        """Ensure that the method returns the class object"""
        self.assertEqual(Organization, OrganizationMixin().get_org_model())
        self.assertEqual(Organization, OrganizationUserMixin().get_org_model())
        self.assertEqual(OrganizationUser,
                OrganizationUserMixin().get_user_model())


class AccessMixinTests(TestCase):

    fixtures = ['users.json', 'orgs.json']

    def setUp(self):
        self.nirvana = Organization.objects.get(name="Nirvana")
        self.kurt = User.objects.get(username="kurt")
        self.krist = User.objects.get(username="krist")
        self.dave = User.objects.get(username="dave")
        self.dummy = User.objects.create_user("dummy",
                email="dummy@example.com", password="test")
        self.factory = RequestFactory()
        self.kurt_request = request_factory_login(self.factory, self.kurt)
        self.krist_request = request_factory_login(self.factory, self.krist)
        self.dave_request = request_factory_login(self.factory, self.dave)
        self.dummy_request = request_factory_login(self.factory, self.dummy)

    def test_member_access(self):
        class MemberView(MembershipRequiredMixin, OrgView):
            pass
        self.assertEqual(200, MemberView().dispatch(self.kurt_request,
            organization_pk=self.nirvana.pk).status_code)
        self.assertEqual(200, MemberView().dispatch(self.krist_request,
            organization_pk=self.nirvana.pk).status_code)
        self.assertEqual(200, MemberView().dispatch(self.dave_request,
            organization_pk=self.nirvana.pk).status_code)
        self.assertEqual(403, MemberView().dispatch(self.dummy_request,
            organization_pk=self.nirvana.pk).status_code)

    def test_admin_access(self):
        class AdminView(AdminRequiredMixin, OrgView):
            pass
        self.assertEqual(200, AdminView().dispatch(self.kurt_request,
            organization_pk=self.nirvana.pk).status_code)
        self.assertEqual(200, AdminView().dispatch(self.krist_request,
            organization_pk=self.nirvana.pk).status_code)
        self.assertEqual(403, AdminView().dispatch(self.dave_request,
            organization_pk=self.nirvana.pk).status_code)
        self.assertEqual(403, AdminView().dispatch(self.dummy_request,
            organization_pk=self.nirvana.pk).status_code)

    def test_owner_access(self):
        class OwnerView(OwnerRequiredMixin, OrgView):
            pass
        self.assertEqual(200, OwnerView().dispatch(self.kurt_request,
            organization_pk=self.nirvana.pk).status_code)
        self.assertEqual(403, OwnerView().dispatch(self.krist_request,
            organization_pk=self.nirvana.pk).status_code)
        self.assertEqual(403, OwnerView().dispatch(self.dave_request,
            organization_pk=self.nirvana.pk).status_code)
        self.assertEqual(403, OwnerView().dispatch(self.dummy_request,
            organization_pk=self.nirvana.pk).status_code)





from django import template

register = template.Library()


@register.inclusion_tag('organizations/organization_users.html')
def organization_users(org):
    return {'organization_users': org.organization_users.all()}



from django.core import mail
from django.core.urlresolvers import reverse
from django.contrib.auth.models import User
from django.http import Http404, QueryDict
from django.test import TestCase
from django.test.client import RequestFactory

from organizations.tests.utils import request_factory_login
from organizations.backends.defaults import (BaseBackend, InvitationBackend,
        RegistrationBackend)
from organizations.backends.tokens import RegistrationTokenGenerator


class BaseTests(TestCase):

    def test_generate_username(self):
        self.assertTrue(BaseBackend().get_username())


class InvitationTests(TestCase):

    fixtures = ['users.json', 'orgs.json']

    def setUp(self):
        mail.outbox = []
        self.factory = RequestFactory()
        self.tokenizer = RegistrationTokenGenerator()
        self.user = User.objects.get(username="krist")
        self.pending_user = User.objects.create_user(username="theresa",
                email="t@example.com", password="test")
        self.pending_user.is_active = False
        self.pending_user.save()

    def test_backend_definition(self):
        from organizations.backends import invitation_backend
        self.assertTrue(isinstance(invitation_backend(), InvitationBackend))

    def test_create_user(self):
        invited = InvitationBackend().invite_by_email("sedgewick@example.com")
        self.assertTrue(isinstance(invited, User))
        self.assertFalse(invited.is_active)
        self.assertEqual(1, len(mail.outbox))
        mail.outbox = []

    def test_create_existing_user(self):
        invited = InvitationBackend().invite_by_email(self.user.email)
        self.assertEqual(self.user, invited)
        self.assertEqual(0, len(mail.outbox)) # User is active

    def test_send_reminder(self):
        InvitationBackend().send_reminder(self.pending_user)
        self.assertEqual(1, len(mail.outbox))
        InvitationBackend().send_reminder(self.user)
        self.assertEqual(1, len(mail.outbox)) # User is active
        mail.outbox = []

    def test_urls(self):
        """Ensure no error is raised"""
        reverse('invitations_register', kwargs={
            'user_id': self.pending_user.id,
            'token': self.tokenizer.make_token(self.pending_user)})

    def test_activate_user(self):
        request = self.factory.request()
        with self.assertRaises(Http404):
            InvitationBackend().activate_view(request, self.user.id,
                    self.tokenizer.make_token(self.user))
        self.assertEqual(200, InvitationBackend().activate_view(request,
            self.pending_user.id,
            self.tokenizer.make_token(self.pending_user)).status_code)


class RegistrationTests(TestCase):

    fixtures = ['users.json', 'orgs.json']

    def setUp(self):
        mail.outbox = []
        self.factory = RequestFactory()
        self.tokenizer = RegistrationTokenGenerator()
        self.user = User.objects.get(username="krist")
        self.pending_user = User.objects.create_user(username="theresa",
                email="t@example.com", password="test")
        self.pending_user.is_active = False
        self.pending_user.save()

    def test_backend_definition(self):
        from organizations.backends import registration_backend
        self.assertTrue(isinstance(registration_backend(), RegistrationBackend))

    def test_register_authenticated(self):
        """Ensure an already authenticated user is redirected"""
        backend = RegistrationBackend()
        request = request_factory_login(self.factory, self.user)
        self.assertEqual(302, backend.create_view(request).status_code)

    def test_register_existing(self):
        """Ensure that an existing user is redirected to login"""
        backend = RegistrationBackend()
        request = request_factory_login(self.factory)
        request.POST = QueryDict("name=Mudhoney&slug=mudhoney&email=dave@foo.com")
        self.assertEqual(302, backend.create_view(request).status_code)

    def test_create_user(self):
        registered = RegistrationBackend().register_by_email("greenway@example.com")
        self.assertTrue(isinstance(registered, User))
        self.assertFalse(registered.is_active)
        self.assertEqual(1, len(mail.outbox))
        mail.outbox = []

    def test_create_existing_user(self):
        registered = RegistrationBackend().register_by_email(self.user.email)
        self.assertEqual(self.user, registered)
        self.assertEqual(0, len(mail.outbox)) # User is active

    def test_send_reminder(self):
        RegistrationBackend().send_reminder(self.pending_user)
        self.assertEqual(1, len(mail.outbox))
        RegistrationBackend().send_reminder(self.user)
        self.assertEqual(1, len(mail.outbox)) # User is active
        mail.outbox = []

    def test_urls(self):
        reverse('registration_register', kwargs={
            'user_id': self.pending_user.id,
            'token': self.tokenizer.make_token(self.pending_user)})

    def test_activate_user(self):
        request = self.factory.request()
        with self.assertRaises(Http404):
            RegistrationBackend().activate_view(request, self.user.id,
                    self.tokenizer.make_token(self.user))
        self.assertEqual(200, RegistrationBackend().activate_view(request,
            self.pending_user.id,
            self.tokenizer.make_token(self.pending_user)).status_code)



from django.contrib import admin

from organizations.models import (Organization, OrganizationUser,
        OrganizationOwner)


class OwnerInline(admin.StackedInline):
    model = OrganizationOwner


class OrganizationAdmin(admin.ModelAdmin):
    inlines = [OwnerInline]
    list_display = ['name', 'is_active']


class OrganizationUserAdmin(admin.ModelAdmin):
    list_filter = ['organization']
    list_display = ['user', 'organization', 'is_admin']


class OrganizationOwnerAdmin(admin.ModelAdmin):
    list_filter = ['organization']


admin.site.register(Organization, OrganizationAdmin)
admin.site.register(OrganizationUser, OrganizationUserAdmin)
admin.site.register(OrganizationOwner, OrganizationOwnerAdmin)



from django.test import TestCase
from django.test.client import RequestFactory

from organizations.forms import OrganizationForm, OrganizationUserForm
from organizations.models import Organization
from organizations.tests.utils import request_factory_login


class OrgFormTests(TestCase):

    fixtures = ['users.json', 'orgs.json']

    def setUp(self):
        self.factory = RequestFactory()
        self.org = Organization.objects.get(name="Nirvana")
        self.admin = self.org.organization_users.get(user__username="krist")
        self.owner = self.org.organization_users.get(user__username="kurt")

    def test_admin_edits_org(self):
        user = self.admin.user
        request = request_factory_login(self.factory, user)
        form = OrganizationForm(request, instance=self.org, data={
            'name': self.org.name, 'slug': self.org.slug,
            'owner': self.owner.id})
        self.assertTrue(form.is_valid())
        form = OrganizationForm(request, instance=self.org, data={
            'name': self.org.name, 'slug': self.org.slug,
            'owner': self.admin.id})
        self.assertFalse(form.is_valid())

    def test_owner_edits_org(self):
        user = self.owner.user
        request = request_factory_login(self.factory, user)
        form = OrganizationForm(request, instance=self.org, data={
            'name': self.org.name, 'slug': self.org.slug,
            'owner': self.owner.id})
        self.assertTrue(form.is_valid())

    def test_edit_owner_user(self):
        form = OrganizationUserForm(instance=self.owner,
                data={'is_admin': True})
        self.assertTrue(form.is_valid())
        form = OrganizationUserForm(instance=self.owner,
                data={'is_admin': False})
        self.assertFalse(form.is_valid())

    def test_save_org_form(self):
        request = request_factory_login(self.factory, self.owner.user)
        form = OrganizationForm(request, instance=self.org, data={
                'name': self.org.name, 'slug': self.org.slug,
                'owner': self.owner.id})
        self.assertTrue(form.is_valid())
        form.save()

    def test_save_user_form(self):
        form = OrganizationUserForm(instance=self.owner,
                data={'is_admin': True})
        self.assertTrue(form.is_valid())
        form.save()




#!/usr/bin/env python

import os, sys

parent = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
sys.path.insert(0, parent)

os.environ['DJANGO_SETTINGS_MODULE'] = 'tests.settings'

from django.test.simple import run_tests

def runtests():
    failures = run_tests(['tests'], verbosity=1, interactive=True)
    sys.exit(failures)

if __name__ == '__main__':
    runtests()



import uuid

from django.conf import settings
from django.conf.urls.defaults import patterns, url
from django.contrib.auth import authenticate, login
from django.contrib.auth.models import User
from django.core.urlresolvers import reverse
from django.core.exceptions import ImproperlyConfigured
from django.core.mail import EmailMessage
from django.http import Http404, HttpResponseRedirect
from django.shortcuts import render_to_response
from django.template import RequestContext, Context, loader
from django.utils.translation import ugettext as _

from organizations.backends.tokens import RegistrationTokenGenerator
from organizations.backends.forms import (UserRegistrationForm,
        OrganizationRegistrationForm)
from organizations.utils import create_organization


# Backend classes should provide common interface


class BaseBackend(object):
    """Base backend class for registering and inviting users to an organization
    """

    def get_urls(self):
        raise NotImplementedError

    def get_success_url(self):
        """Will return the class's `success_url` attribute unless overridden"""
        raise NotImplementedError

    def get_form(self, **kwargs):
        """Returns the form for registering or inviting a user"""
        if not hasattr(self, 'form_class'):
            raise AttributeError("You must define a form_class")
        return self.form_class(**kwargs)

    def get_token(self, user, **kwargs):
        """Returns a unique token for the given user"""
        return RegistrationTokenGenerator().make_token(user)

    def get_username(self):
        return unicode(uuid.uuid4()).replace("-", "")[:30]

    def activate_view(self, request, user_id, token):
        """
        Activates the given User by setting `is_active` to true if the provided
        information is verified.
        """
        try:
            user = User.objects.get(id=user_id, is_active=False)
        except User.DoesNotExist:
            raise Http404(_("Your URL may have expired."))
        if not RegistrationTokenGenerator().check_token(user, token):
            raise Http404(_("Your URL may have expired."))
        form = self.get_form(data=request.POST or None, instance=user)
        if form.is_valid():
            form.instance.is_active = True
            user = form.save()
            user.set_password(form.cleaned_data['password'])
            user.save()
            user = authenticate(username=form.cleaned_data['username'],
                    password=form.cleaned_data['password'])
            login(request, user)
            return HttpResponseRedirect(self.get_success_url())
        return render_to_response('organizations/register_form.html',
                {'form': form}, context_instance=RequestContext(request))

    def send_reminder(self, user, sender=None, **kwargs):
        """Sends a reminder email to the specified user"""
        if user.is_active:
            return False
        token = RegistrationTokenGenerator().make_token(user)
        kwargs.update({'token': token})
        self._send_email(user, self.reminder_subject, self.reminder_body,
                sender, **kwargs)

    def _send_email(self, user, subject_template, body_template,
            sender=None, **kwargs):
        """Utility method for sending emails to new users"""
        if not sender:
            try:
                from_email = settings.DEFAULT_FROM_EMAIL
            except AttributeError:
                raise ImproperlyConfigured(_("You must define DEFAULT_FROM_EMAIL in your settings"))

        if sender:
            from_email = "%s %s <%s>" % (sender.first_name, sender.last_name,
                    from_email)
            reply_to = "%s %s <%s>" % (sender.first_name, sender.last_name,
                    sender.email)
        headers = {'Reply-To': reply_to} if sender else {}

        kwargs.update({'sender': sender, 'user': user})
        ctx = Context(kwargs)

        subject_template = loader.get_template(subject_template)
        body_template = loader.get_template(body_template)
        subject = subject_template.render(ctx).strip() # Remove stray newline characters
        body = body_template.render(ctx)
        return EmailMessage(subject, body, from_email, [user.email],
                headers).send()


class RegistrationBackend(BaseBackend):
    """A backend for allowing new users to join the site by creating a new user
    associated with a new organization.
    """
    activation_subject = 'organizations/email/activation_subject.txt'
    activation_body = 'organizations/email/activation_body.html'
    reminder_subject = 'organizations/email/reminder_subject.txt'
    reminder_body = 'organizations/email/reminder_body.html'
    form_class = UserRegistrationForm

    def get_success_url(self):
        return reverse('registration_success')

    def get_urls(self):
        return patterns('',
            url(r'^complete/$', view=self.success_view,
                name="registration_success"),
            url(r'^(?P<user_id>[\d]+)-(?P<token>[0-9A-Za-z]{1,13}-[0-9A-Za-z]{1,20})/$',
                view=self.activate_view, name="registration_register"),
            url(r'^$', view=self.create_view, name="registration_create"),
            )

    def register_by_email(self, email, sender=None, request=None, **kwargs):
        """
        Returns a User object filled with dummy data and not active, and sends
        an invitation email.
        """
        try:
            user = User.objects.get(email=email)
        except User.DoesNotExist:
            user = User.objects.create(username=self.get_username(),
                    email=email)
            user.is_active = False
            user.save()
        self.send_activation(user, sender, **kwargs)
        return user

    def send_activation(self, user, sender=None, **kwargs):
        """
        Invites a user to join the site
        """
        if user.is_active:
            return False
        token = self.get_token(user)
        kwargs.update({'token': token})
        self._send_email(user, self.activation_subject, self.activation_body,
                sender, **kwargs)

    def create_view(self, request):
        """
        Initiates the organization and user account creation process
        """
        if request.user.is_authenticated():
            return HttpResponseRedirect(reverse("organization_add"))
        form = OrganizationRegistrationForm(request.POST or None)
        if form.is_valid():
            try:
                user = User.objects.get(email=form.cleaned_data['email'])
            except User.DoesNotExist:
                user = User.objects.create(username=self.get_username(),
                        email=form.cleaned_data['email'])
                user.is_active = False
                user.save()
            else:
                return HttpResponseRedirect(reverse("organization_add"))
            organization = create_organization(user, form.cleaned_data['name'],
                    form.cleaned_data['slug'], is_active=False)
            return render_to_response('organizations/register_success.html',
                    {'user': user, 'organization': organization},
                    context_instance=RequestContext(request))
        return render_to_response('organizations/register_form.html',
                {'form': form}, context_instance=RequestContext(request))

    def success_view(self, request):
        return render_to_response('organizations/register_success.html',
                {}, context_instance=RequestContext(request))


class InvitationBackend(BaseBackend):
    """A backend for inviting new users to join the site as members of an
    organization.
    """
    invitation_subject = 'organizations/email/invitation_subject.txt'
    invitation_body = 'organizations/email/invitation_body.html'
    reminder_subject = 'organizations/email/reminder_subject.txt'
    reminder_body = 'organizations/email/reminder_body.html'
    form_class = UserRegistrationForm

    def get_success_url(self):
        return reverse('organization_list')

    def get_urls(self):
        return patterns('',
            url(r'^(?P<user_id>[\d]+)-(?P<token>[0-9A-Za-z]{1,13}-[0-9A-Za-z]{1,20})/$',
                view=self.activate_view, name="invitations_register"),
            )

    def invite_by_email(self, email, sender=None, request=None, **kwargs):
        """Creates an inactive user with the information we know and then sends
        an invitation email for that user to complete registration.

        If your project uses email in a different way then you should make to
        extend this method as it only checks the `email` attribute for Users.
        """
        try:
            user = User.objects.get(email=email)
        except User.DoesNotExist:
            user = User.objects.create(username=self.get_username(),
                    email=email)
            user.is_active = False
            user.save()
        self.send_invitation(user, sender, **kwargs)
        return user

    def send_invitation(self, user, sender=None, **kwargs):
        """An intermediary function for sending an invitation email that
        selects the templates, generating the token, and ensuring that the user
        has not already joined the site.
        """
        if user.is_active:
            return False
        token = self.get_token(user)
        kwargs.update({'token': token})
        self._send_email(user, self.invitation_subject, self.invitation_body,
                sender, **kwargs)



from django.test import TestCase
from django.contrib.auth.models import User

from organizations.models import Organization
from organizations.utils import create_organization, model_field_attr


class OrgManagerTests(TestCase):

    fixtures = ['users.json', 'orgs.json']

    def test_create_organization(self):
        user = User.objects.get(username="dave")
        acme = create_organization(user, "Acme", "acme")
        self.assertTrue(isinstance(acme, Organization))
        self.assertEqual(user, acme.owner.organization_user.user)


class AttributeUtilTests(TestCase):

    def test_present_field(self):
        self.assertTrue(model_field_attr(User, 'username', 'max_length'))

    def test_absent_field(self):
        self.assertRaises(KeyError, model_field_attr, User, 'blahblah',
            'max_length')

    def test_absent_attr(self):
        self.assertRaises(AttributeError, model_field_attr, User, 'username',
            'mariopoints')



from django.contrib.auth.models import User
from django.http import Http404
from django.test import TestCase
from django.test.client import RequestFactory

from organizations.models import Organization
from organizations.tests.utils import request_factory_login
from organizations.views import (BaseOrganizationList, BaseOrganizationDetail,
        BaseOrganizationCreate, BaseOrganizationUpdate, BaseOrganizationDelete,
        BaseOrganizationUserList, BaseOrganizationUserDetail,
        BaseOrganizationUserCreate, BaseOrganizationUserUpdate,
        BaseOrganizationUserDelete, OrganizationSignup)


class BaseViewTests(TestCase):

    fixtures = ['users.json', 'orgs.json']

    def setUp(self):
        self.kurt = User.objects.get(username="kurt")
        self.dave = User.objects.get(username="dave")
        self.dummy = User.objects.create_user("dummy",
                email="dummy@example.com", password="test")
        self.nirvana = Organization.objects.get(name="Nirvana")
        self.factory = RequestFactory()
        self.kurt_request = request_factory_login(self.factory, self.kurt)
        self.dave_request = request_factory_login(self.factory, self.dave)
        self.anon_request = request_factory_login(self.factory)

    def test_org_list(self):
        """Ensure that the status code 200 is returned"""
        self.assertEqual(200, BaseOrganizationList(
                request=self.kurt_request).get(self.kurt_request).status_code)
        self.assertEqual(200, BaseOrganizationList(
                request=self.dave_request).get(self.dave_request).status_code)

    def test_org_list_queryset(self):
        """Ensure only active organizations belonging to the user are listed"""
        self.assertEqual(1, BaseOrganizationList(
                request=self.kurt_request).get_queryset().count())
        self.assertEqual(2, BaseOrganizationList(
                request=self.dave_request).get_queryset().count())

    def test_org_detail(self):
        kwargs = {'organization_pk': self.nirvana.pk}
        self.assertEqual(200, BaseOrganizationDetail(
            request=self.kurt_request, kwargs=kwargs).get(self.kurt_request,
                **kwargs).status_code)

    def test_org_create(self):
        self.assertEqual(200, BaseOrganizationCreate(
            request=self.kurt_request).get(self.kurt_request).status_code)

    def test_org_update(self):
        kwargs = {'organization_pk': self.nirvana.pk}
        self.assertEqual(200, BaseOrganizationUpdate(
            request=self.kurt_request, kwargs=kwargs).get(self.kurt_request,
                **kwargs).status_code)

    def test_org_delete(self):
        kwargs = {'organization_pk': self.nirvana.pk}
        self.assertEqual(200, BaseOrganizationDelete(
            request=self.kurt_request, kwargs=kwargs).get(self.kurt_request,
                **kwargs).status_code)

    def test_user_list(self):
        kwargs = {'organization_pk': self.nirvana.pk}
        self.assertEqual(200, BaseOrganizationUserList(
            request=self.kurt_request, kwargs=kwargs).get(self.kurt_request,
                **kwargs).status_code)

    def test_user_detail(self):
        kwargs = {'organization_pk': self.nirvana.pk, 'user_pk': self.kurt.pk}
        self.assertEqual(200, BaseOrganizationUserDetail(
            request=self.kurt_request, kwargs=kwargs).get(self.kurt_request,
                **kwargs).status_code)

    def test_bad_user_detail(self):
        kwargs = {'organization_pk': self.nirvana.pk, 'user_pk': self.dummy.pk}
        self.assertRaises(Http404, BaseOrganizationUserDetail(
            request=self.kurt_request, kwargs=kwargs).get, self.kurt_request,
                **kwargs)

    def test_user_create(self):
        kwargs = {'organization_pk': self.nirvana.pk}
        self.assertEqual(200, BaseOrganizationUserCreate(
            request=self.kurt_request, kwargs=kwargs).get(self.kurt_request,
                **kwargs).status_code)

    def test_user_update(self):
        kwargs = {'organization_pk': self.nirvana.pk, 'user_pk': self.kurt.pk}
        self.assertEqual(200, BaseOrganizationUserUpdate(
            request=self.kurt_request, kwargs=kwargs).get(self.kurt_request,
                **kwargs).status_code)

    def test_user_delete(self):
        kwargs = {'organization_pk': self.nirvana.pk, 'user_pk': self.kurt.pk}
        self.assertEqual(200, BaseOrganizationUserDelete(
            request=self.kurt_request, kwargs=kwargs).get(self.kurt_request,
                **kwargs).status_code)

    def test_signup(self):
        """Ensure logged in users are redirected"""
        self.assertEqual(302,
                OrganizationSignup(request=self.kurt_request).dispatch(
                self.kurt_request).status_code)
        self.assertEqual(200,
                OrganizationSignup(request=self.anon_request).dispatch(
                self.anon_request).status_code)



from django.test import TestCase

from testing_utils import AccountUserTestingMixin


class AccountFormTest(AccountUserTestingMixin, TestCase):
    """
    The AccountForm should allow a user to easily create or edit an existing
    account. That includes updating or creating an account user.
    """
    def setUp(self):
        self.user, self.seconduser, self.thirduser, self.fourthuser = self.create_users()

    def test_duplicate_subdomain(self):
        """Subdomains must be unique or form is not valid"""
        from accounts.forms import AccountForm
        from accounts.utils import create_account
        account = create_account("First", self.user, subdomain="first")
        form = AccountForm(initial={
            "name": "My test",
            "subdomain": "first",
        })
        self.assertFalse(form.is_valid())

    def test_duplicate_domain(self):
        """Full domains must be unique or form is not valid"""
        from accounts.forms import AccountForm
        from accounts.utils import create_account
        account = create_account("First", self.user,
                domain="sub.example.com")
        form = AccountForm(initial={
            "name": "My test",
            "domain": "sub.example.com",
        })
        self.assertFalse(form.is_valid())

    def test_create_account_new_user(self):
        """Ensure valid when all fresh information"""
        pass

    def test_create_account_exist_user(self):
        """Ensure valid for existing user"""
        pass


class AccountUserFormsTest(TestCase, AccountUserTestingMixin):
    """
    The AccountUserForm should allow a user to easily create or edit existing
    user. This includes underlying User information.
    """
    def setUp(self):
        pass

    def test_duplicate_user(self):
        """A form creating a duplicate User should not be valid"""
        pass

    def test_add_user_account(self):
        """AccountUserAddForm properly validates with valid data?"""
        from accounts.forms import AccountUserAddForm
        form = AccountUserAddForm({
            'username': 'lol1986',
            'first_name': 'First',
            'last_name': 'Last',
            'email': 'user@exmaple.com',
            'is_admin': False,
        })
        self.assertTrue(form.is_valid())



from setuptools import setup, find_packages
import os


setup(
    author="Ben Lopatin",
    author_email="ben.lopatin@wellfireinteractive.com",
    name='django-organizations',
    version='0.1.3',
    description='Group accounts for Django',
    long_description=open(os.path.join(os.path.dirname(__file__),
        'README.rst')).read(),
    url='https://github.com/bennylope/django-organizations/',
    license='BSD License',
    platforms=['OS Independent'],
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Framework :: Django',
    ],
    install_requires=[
        'Django>=1.4',
    ],
    #test_suite='tests.runtests.runtests',
    include_package_data=True,
    packages=find_packages(exclude=["tests.tests", "tests.test_app", "tests"]),
    zip_safe=False
)
